==> jc-1.4.0.tar.gz: java/lang/NullPointerException.h <==
// public class java.lang.NullPointerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_NullPointerException_H_
#define _JC_java_lang_NullPointerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NullPointerException$sub_refs	_jc_java_lang_NullPointerException$sub_refs;
typedef struct _jc_java_lang_NullPointerException$sub_nonrefs	_jc_java_lang_NullPointerException$sub_nonrefs;
typedef struct _jc_java_lang_NullPointerException$refs	_jc_java_lang_NullPointerException$refs;
typedef struct _jc_java_lang_NullPointerException$nonrefs	_jc_java_lang_NullPointerException$nonrefs;
typedef struct _jc_java_lang_NullPointerException$object	_jc_java_lang_NullPointerException$object;

typedef struct _jc_java_lang_NullPointerException$fields_struct	_jc_java_lang_NullPointerException$fields_struct;
typedef const struct _jc_java_lang_NullPointerException$vmethods	_jc_java_lang_NullPointerException$vmethods;
typedef const struct _jc_java_lang_NullPointerException$vtable	_jc_java_lang_NullPointerException$vtable;
typedef const struct _jc_java_lang_NullPointerException$vtype	_jc_java_lang_NullPointerException$vtype;

// Class fields structure
struct _jc_java_lang_NullPointerException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NullPointerException$fields_struct _jc_java_lang_NullPointerException$class_fields;

// Constructors
extern void _jc_java_lang_NullPointerException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NullPointerException$object *);
extern void _jc_java_lang_NullPointerException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NullPointerException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_NullPointerException$vmethods {
};

// Vtable
struct _jc_java_lang_NullPointerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_NullPointerException$vmethods	java_lang_NullPointerException;
};

// Vtype
struct _jc_java_lang_NullPointerException$vtype {
	_jc_type			type;
	_jc_java_lang_NullPointerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NullPointerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NullPointerException$refs {
    _jc_java_lang_NullPointerException$sub_refs	java_lang_NullPointerException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NullPointerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NullPointerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_NullPointerException$sub_nonrefs	java_lang_NullPointerException;
};

// Object instance structure
struct _jc_java_lang_NullPointerException$object {
	_jc_java_lang_NullPointerException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NullPointerException$vtype	*vtype;
	_jc_java_lang_NullPointerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NullPointerException$vtype _jc_java_lang_NullPointerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NullPointerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NullPointerException$class_object;

#endif	/* _JC_java_lang_NullPointerException_H_ */

==> jc-1.4.6.tar.gz: java/lang/NullPointerException.h <==
// public class java.lang.NullPointerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_NullPointerException_H_
#define _JC_java_lang_NullPointerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NullPointerException$sub_refs	_jc_java_lang_NullPointerException$sub_refs;
typedef struct _jc_java_lang_NullPointerException$sub_nonrefs	_jc_java_lang_NullPointerException$sub_nonrefs;
typedef struct _jc_java_lang_NullPointerException$refs	_jc_java_lang_NullPointerException$refs;
typedef struct _jc_java_lang_NullPointerException$nonrefs	_jc_java_lang_NullPointerException$nonrefs;
typedef struct _jc_java_lang_NullPointerException$object	_jc_java_lang_NullPointerException$object;

typedef struct _jc_java_lang_NullPointerException$fields_struct	_jc_java_lang_NullPointerException$fields_struct;
typedef const struct _jc_java_lang_NullPointerException$vmethods	_jc_java_lang_NullPointerException$vmethods;
typedef const struct _jc_java_lang_NullPointerException$vtable	_jc_java_lang_NullPointerException$vtable;
typedef const struct _jc_java_lang_NullPointerException$vtype	_jc_java_lang_NullPointerException$vtype;

// Class fields structure
struct _jc_java_lang_NullPointerException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NullPointerException$fields_struct _jc_java_lang_NullPointerException$class_fields;

// Constructors
extern void _jc_java_lang_NullPointerException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NullPointerException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_NullPointerException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NullPointerException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_NullPointerException$vmethods {
};

// Vtable
struct _jc_java_lang_NullPointerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_NullPointerException$vmethods	java_lang_NullPointerException;
};

// Vtype
struct _jc_java_lang_NullPointerException$vtype {
	_jc_type			type;
	_jc_java_lang_NullPointerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NullPointerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NullPointerException$refs {
    _jc_java_lang_NullPointerException$sub_refs	java_lang_NullPointerException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NullPointerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NullPointerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_NullPointerException$sub_nonrefs	java_lang_NullPointerException;
};

// Object instance structure
struct _jc_java_lang_NullPointerException$object {
	_jc_java_lang_NullPointerException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NullPointerException$vtype	*vtype;
	_jc_java_lang_NullPointerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NullPointerException$vtype _jc_java_lang_NullPointerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NullPointerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NullPointerException$class_object;

#endif	/* _JC_java_lang_NullPointerException_H_ */
